@@ -4,8 +4,9 @@ compare_opts <- function(...,
                          ignore_srcref = TRUE,
                          ignore_attr = FALSE,
                          ignore_encoding = TRUE,
+                         ignore_function_env = FALSE,
                          ignore_formula_env = FALSE,
-                         ignore_function_env = FALSE
+                         list_as_map = FALSE
                          ) {
 
   base <- old_opts(...)
@@ -16,8 +17,9 @@ compare_opts <- function(...,
     ignore_srcref = ignore_srcref,
     ignore_attr = ignore_attr,
     ignore_encoding = ignore_encoding,
+    ignore_function_env = ignore_function_env,
     ignore_formula_env = ignore_formula_env,
-    ignore_function_env = ignore_function_env
+    list_as_map = list_as_map
   )
 
   utils::modifyList(waldo, base)
@@ -42,9 +44,12 @@ old_opts <- function(..., tol, check.attributes, checkNames) {
   }
 
   if (!missing(...)) {
-    args <- names(substitute(alist(...))[-1])
-    args2 <- encodeString(args, quote = "`")
-    warn(paste0("Other arguments (", paste0(args2, collapse = ', '), ") ignored"))
+    args <- substitute(...())
+    exprs <- vapply(args, expr_deparse, character(1))
+    names <- names2(args)
+    exprs <- ifelse(names == "", exprs, paste0(names, " = ", exprs))
+
+    warn(paste0("Unused arguments (", paste0(exprs, collapse = ', '), ")"))
   }
 
   out
